/**
 * Sharedaddy Admin Styles
 */
#services-config {
  min-width: 700px;
  width: 100%;
  float: right;
}

#services-config h3 {
  font-weight: normal;
  font-size: 15px;
  margin: 0;
  padding: 8px 10px;
  overflow: hidden;
  white-space: nowrap;
  color: #464646;
}

#available-services, #enabled-services, #live-preview {
  padding: 0;
  width: 100%;
  padding-top: 20px;
  border-spacing: 0;
}

#enabled-services .ui-sortable {
  min-height: 50px;
}

#enabled-services {
  padding-bottom: 20px;
}

#available-services, #enabled-services {
  border-bottom: 2px solid #cccccc;
}

#live-preview {
  border-bottom: 1px solid #dcdcde;
  padding-bottom: 60px;
}

#available-services h3, #enabled-services h3, #live-preview h3 {
  padding: 0px;
  margin-top: 0px;
  margin-bottom: 1em;
}

body.settings_page_sharing .description {
  width: 180px;
  vertical-align: top;
}

body.settings_page_sharing .description p {
  font-size: 13px;
  font-style: italic;
}

body.settings_page_sharing .services {
  padding: 0px 20px;
  vertical-align: top;
}

body.settings_page_sharing .services ul li {
  cursor: move;
}

body.settings_page_sharing .services ul li.divider {
  border: none;
  padding: 0;
  background: none;
  cursor: default;
}

body.settings_page_sharing ul.services-hidden {
  margin-bottom: 0;
}

/* Generic style */
#available-services .service, #enabled-services .service {
  color: #2C3338 !important;
  display: inline-block;
  font-family: "Open Sans", sans-serif;
  font-size: 13px;
  font-weight: 500;
  line-height: 23px;
  margin: 0 0 8px 8px;
  padding: 3px 9px 4px 11px;
  border-radius: 4px;
  background: #fff;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.12), 0 0 0 1px rgba(0, 0, 0, 0.12);
}

#available-services .service .options-left, #enabled-services .service .options-left {
  align-items: center;
  display: flex;
}

#available-services .service:hover, #enabled-services .service:hover {
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.22), 0 0 0 1px rgba(0, 0, 0, 0.22);
}

#available-services .service.share-deprecated,
#enabled-services .service.share-deprecated {
  opacity: 0.5;
  padding: 5px;
  text-decoration: line-through;
}

#available-services .service.share-deprecated {
  display: none;
}

/* Generic style icons */
li.service span:before {
  -webkit-font-smoothing: antialiased;
  font: normal 18px/1 "social-logos";
  position: relative;
  top: -1px;
  margin-left: 6px;
  width: 16px;
  height: 16px;
}

li.service.share-print span:before {
  content: "\f469";
}

li.service.share-digg span:before {
  content: "\f221";
}

li.service.share-email span:before {
  content: "\f410";
}

li.service.share-linkedin span:before {
  content: "\f207";
}

li.service.share-twitter span:before {
  content: "\f202";
}

li.service.share-reddit span:before {
  content: "\f222";
}

li.service.share-tumblr span:before {
  content: "\f214";
}

li.service.share-pocket span:before {
  content: "\f224";
}

li.service.share-pinterest span:before {
  content: "\f209";
}

li.service.share-facebook span:before {
  content: "\f203";
}

li.service.share-press-this span:before { /* Fixme: remove this button in favor of reblog */
  content: "\f205";
}

li.service.share-telegram span:before {
  content: "\f606";
}

li.service.share-threads span:before {
  content: "\f10d";
}

li.service.share-jetpack-whatsapp span:before {
  content: "\f608";
}

li.service.share-mastodon span:before {
  content: "\f10a";
}

li.service.share-nextdoor span:before {
  content: "\f10c";
}

li.service.share-x span:before {
  content: "\f10e";
}

li.service.share-bluesky span:before {
  content: "\f10f";
}

/**
 * Preview section
 */
body.settings_page_sharing ul.preview {
  display: flex;
  flex-wrap: wrap;
  float: right;
}

body.settings_page_sharing ul.preview li.preview-item, body.settings_page_sharing ul.preview li.preview-item a {
  cursor: default;
  text-decoration: none;
}

div.sd-social-icon ul.preview li.preview-item a span,
div.sd-social-icon .inner li.preview-item a span {
  display: none;
}

div.sd-social-icon ul.preview li.preview-item.preview-custom a span {
  display: inline-block;
}

.services .preview li.share-custom a {
  text-decoration: none;
}

.services ul li.end-fix {
  clear: both;
  float: none;
  visibility: hidden;
  padding: 0;
  margin: 0;
  height: 20px;
  width: 0;
}

#enabled-services h2 {
  font-size: 20px;
  padding-top: 0px;
  font-weight: normal !important;
  color: #999;
}

body.settings_page_sharing #live-preview h2 {
  font-size: 20px;
  font-weight: normal !important;
  color: #e3e3e3;
}

body.settings_page_sharing .clearing {
  clear: both;
}

body.settings_page_sharing .options .options-left {
  float: right;
}

body.settings_page_sharing .input label {
  font-size: 11px;
  line-height: 16px;
}

body.settings_page_sharing .advanced-form {
  padding: 10px 10px 8px 14px;
  margin-right: -24px;
  display: none;
  border-top: 1px #e3e3e3 solid;
  margin-top: 4px;
}

body.settings_page_sharing .utility {
  float: left;
  padding-top: 10px;
  padding-left: 10px;
  font-size: 10px;
}

body.settings_page_sharing .advanced input[type=submit] {
  float: right;
  margin-top: 10px;
  margin-left: 10px;
}

.services li.dropzone {
  border: 1px dashed #999;
  border-radius: 3px;
  background: #e3e3e3;
  margin-left: 10px;
  padding: 5px;
  height: 18px;
}

.advanced-form .form-table th {
  width: auto !important;
}

.advanced-form .button-secondary {
  margin-top: 0 !important;
}

#hidden-drop-target {
  background: #e1e1e1;
  border: 1px solid #cdcdcd;
  width: 29%;
  padding: 10px;
  vertical-align: top;
}

#hidden-drop-target p {
  font-size: 13px;
  font-style: italic;
  margin: 0 0 10px 0;
}

/* Official button previews */
.preview li.preview-item {
  background-position: 0px 5px;
  cursor: default;
}

.preview .option-smart-on {
  margin: 3px 0 0 5px;
}

.preview-digg .option-smart-on {
  background: url(../../modules/sharedaddy/images/smart-digg.png) no-repeat top right;
  background-size: 76px 17px;
  width: 76px;
  height: 17px;
  margin-top: 2px;
}

.preview-facebook .option-smart-on {
  background: url(../../modules/sharedaddy/images/smart-like.png) no-repeat top right;
  background-size: 85px 20px;
  width: 85px;
  height: 20px;
  margin-right: -4px;
}

.preview-twitter .option-smart-on,
.preview-x .option-smart-on {
  background: url(../../modules/sharedaddy/images/smart-x.png) no-repeat top right;
  background-size: 60px 20px;
  width: 60px;
  height: 20px;
}

.preview-linkedin .option-smart-on {
  background: url(../../modules/sharedaddy/images/linkedin-smart.png) no-repeat top center;
  background-size: 99px 18px;
  width: 99px;
  height: 20px;
}

.preview-tumblr .option-smart-on {
  background: url(../../modules/sharedaddy/images/smart-tumblr.png) no-repeat top right;
  background-size: 62px 20px;
  width: 62px;
  height: 20px;
}

.preview-pinterest .option-smart-on {
  background: url(../../modules/sharedaddy/images/smart-pinterest.png) no-repeat top right;
  background-size: 39px 20px;
  width: 39px;
  height: 20px;
}

.preview-pocket .option-smart-on {
  background: url(../../modules/sharedaddy/images/smart-pocket.png) no-repeat top right;
  background-size: 60px 20px;
  width: 60px;
  height: 20px;
}

.preview-item.share-deprecated {
  opacity: 0.5;
}

.preview-item.share-deprecated a span {
  text-decoration: line-through;
}

@media (min-resolution: 120dpi) {
  .preview-digg .option-smart-on {
    background-image: url(../../modules/sharedaddy/images/smart-digg@2x.png);
  }
  .preview-facebook .option-smart-on {
    background-image: url(../../modules/sharedaddy/images/smart-like@2x.png);
  }
  .preview-twitter .option-smart-on,
  .preview-x .option-smart-on {
    background-image: url(../../modules/sharedaddy/images/smart-x@2x.png);
  }
  .preview-linkedin .option-smart-on {
    background-image: url(../../modules/sharedaddy/images/linkedin-smart@2x.png);
  }
  .preview-tumblr .option-smart-on {
    background-image: url(../../modules/sharedaddy/images/smart-tumblr@2x.png);
  }
  .preview-pinterest .option-smart-on {
    background-image: url(../../modules/sharedaddy/images/smart-pinterest@2x.png);
  }
  .preview-pocket .option-smart-on {
    background-image: url(../../modules/sharedaddy/images/smart-pocket@2x.png);
  }
}
/**
 * Overflow sharing dialog
 */
.services .sharing-hidden li {
  background-color: transparent;
}

.sharing-hidden li.share-end {
  clear: both;
  height: 0;
  padding: 0px !important;
  margin: 0px !important;
  width: 0;
  visibility: hidden;
  float: none;
}

.preview .sharing-label {
  font-weight: bold;
  border: 0;
  padding: 4px 0 0 6px;
}

#services-config a.remove {
  background: #dcdcde;
  color: #fff;
  padding: 0px 4px 2px;
  border-radius: 15px;
  -moz-border-radius: 15px;
  -webkit-border-radius: 15px;
  text-decoration: none;
  font-weight: bold;
  font-size: 10px;
}

#services-config a.remove:hover {
  background: #f00;
}

.sd-social-icon .inner a.sd-button span,
.sd-social-icon .inner a.share-icon span {
  display: inline-block;
  overflow: hidden;
  width: 0;
  text-indent: 100%;
}

.sharing-block-message__items-wrapper {
  display: flex;
  flex-wrap: wrap;
  column-gap: 6rem;
}

.sharing-block-message__buttons-wrapper .button {
  margin-left: 1rem;
}

.sharing-block-message__buttons-wrapper .button-primary:visited {
  color: #fff;
}

.admin-sharing-settings__block-theme-description {
  margin-top: 1rem;
  font-style: italic;
}

a.dops-card__link {
  cursor: pointer;
}

.settings-sharing__block-theme-description {
  font-style: italic;
}
